@@ -1,5 +1,3 @@
-import os
-
 from pyswip import Prolog, Query, Functor, Variable
 from datetime import date
 
@@ -11,7 +9,7 @@ class Engine:
 
     def __init__(self, context=date.today()):
         self.context = Functor("date", 3)(context.year, context.month, context.day)
-        Prolog().consult(os.path.join(os.path.dirname(__file__), 'grammar.pl'))
+        next(Prolog().query("use_module(library(abbreviated_dates))"))
 
     def when(self, time_expression: str):
         """
@@ -30,4 +28,3 @@ class Engine:
             syntax = [trace.value for trace in trace.value]
             yield semantic, syntax
         query.closeQuery()
-
